@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2015 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2015 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2016 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2016 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -55,14 +55,14 @@ void Sagan_Alert_File( _SaganEvent *Event )
     fprintf(config->sagan_alert_stream, "%s %s %s:%d -> %s:%d %s %s\n", Event->date, Event->time, Event->ip_src, Event->src_port, Event->ip_dst, Event->dst_port, Event->facility, Event->priority);
     fprintf(config->sagan_alert_stream, "Message: %s\n", Event->message);
 
-    if ( Event->found != 0 )
-        {
-            tmpref = Reference_Lookup( Event->found, 0 );
-            if (strcmp(tmpref, "" ))
-                {
-                    fprintf(config->sagan_alert_stream, "%s\n", Reference_Lookup( Event->found, 0 ));
-                }
+    if ( Event->found != 0 ) {
+
+        tmpref = Reference_Lookup( Event->found, 0 );
+
+        if (strcmp(tmpref, "" )) {
+            fprintf(config->sagan_alert_stream, "%s\n", Reference_Lookup( Event->found, 0 ));
         }
+    }
 
 
     fflush(config->sagan_alert_stream);
