@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2015 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2015 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2016 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2016 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -62,16 +62,14 @@ void Unified2CleanExit( void );
 void Sagan_WriteExtraData( _SaganEvent *, int );
 
 /* Data structure used for serialization of Unified2 Records */
-typedef struct _Serial_Unified2_Header
-{
+typedef struct _Serial_Unified2_Header {
     uint32_t   type;
     uint32_t   length;
 } Serial_Unified2_Header;
 
 //UNIFIED2_PACKET = type 2
 
-typedef struct _Serial_Unified2Packet
-{
+typedef struct _Serial_Unified2Packet {
     uint32_t sensor_id;
     uint32_t event_id;
     uint32_t event_second;
@@ -85,8 +83,7 @@ typedef struct _Serial_Unified2Packet
 //---------------LEGACY, type '7'
 //These structures are not used anymore in the product
 
-typedef struct _Serial_Unified2IDSEvent_legacy
-{
+typedef struct _Serial_Unified2IDSEvent_legacy {
     uint32_t sensor_id;
     uint32_t event_id;
     uint32_t event_second;
@@ -133,14 +130,12 @@ typedef struct _Serial_Unified2IDSEventIPv6_legacy
 
 /* The below is from packet.h from Snort */
 
-struct sf_timeval32
-{
+struct sf_timeval32 {
     uint32_t tv_sec;      /* seconds */
     uint32_t tv_usec;     /* microseconds */
 };
 
-typedef struct _Event
-{
+typedef struct _Event {
     uint32_t sig_generator;   /* which part of snort generated the alert? */
     uint32_t sig_id;          /* sig id for this generator */
     uint32_t sig_rev;         /* sig revision for this id */
@@ -155,15 +150,13 @@ typedef struct _Event
 } Event;
 
 
-typedef enum _EventDataType
-{
+typedef enum _EventDataType {
     EVENT_DATA_TYPE_BLOB = 1,
     EVENT_DATA_TYPE_MAX
-}EventDataType;
+} EventDataType;
 
 //UNIFIED2_EXTRA_DATA - type 110
-typedef struct _SerialUnified2ExtraData
-{
+typedef struct _SerialUnified2ExtraData {
     uint32_t sensor_id;
     uint32_t event_id;
     uint32_t event_second;
@@ -172,15 +165,13 @@ typedef struct _SerialUnified2ExtraData
     uint32_t blob_length;       /* Length of the data + sizeof(blob_length) + sizeof(data_type)*/
 } SerialUnified2ExtraData;
 
-typedef struct _Unified2ExtraDataHdr
-{    
+typedef struct _Unified2ExtraDataHdr {
     uint32_t event_type;
     uint32_t event_length;
 
 } Unified2ExtraDataHdr;
 
-typedef enum _EventInfoEnum
-{
+typedef enum _EventInfoEnum {
     EVENT_INFO_XFF_IPV4 = 1,
     EVENT_INFO_XFF_IPV6,
     EVENT_INFO_REVIEWED_BY,
@@ -194,7 +185,7 @@ typedef enum _EventInfoEnum
     EVENT_INFO_IPV6_SRC,
     EVENT_INFO_IPV6_DST,
     EVENT_INFO_JSNORM_DATA
-}EventInfoEnum;
+} EventInfoEnum;
 
 
 #endif
