@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2015 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2015 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2016 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2016 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -25,8 +25,12 @@
 #include "parsers/sagan-strstr/sagan-strstr-hook.h"
 
 char *Sagan_Parse_IP( char *, int );
-int   Sagan_Parse_Port( char * );
+int   Sagan_Parse_Src_Port( char * );
+int   Sagan_Parse_Dst_Port( char * );
 int   Sagan_Parse_Proto( char * );
-int   Sagan_Parse_Proto_Program (char *);
+int   Sagan_Parse_Proto_Program( char * );
+char *Sagan_Parse_Hash(char *, int );
+char *Sagan_Parse_Hash_Cleanup(char *);
+
 
 
