@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2015 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2015 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2016 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2016 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -24,8 +24,7 @@ sbool Sagan_Blacklist_IPADDR( uint32_t );
 sbool Sagan_Blacklist_IPADDR_All ( char * );
 
 typedef struct _Sagan_Blacklist _Sagan_Blacklist;
-struct _Sagan_Blacklist
-{
+struct _Sagan_Blacklist {
 
     uint32_t u32_lower;
     uint32_t u32_higher;
