@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2015 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2015 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2016 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2016 Adam Hall <ahall@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -18,7 +18,7 @@
 ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-/* sagan-track-clients.c
+/* sagan-track-clients.h
 *
 * Simple pre-processors that keeps track of reporting syslog clients/agents.
 * This is based off the IP address the clients,  not based on normalization.
@@ -27,25 +27,13 @@
 *
 */
 
-#define PROCESSOR_NAME "Sagan_Track_Clients"
-#define PROCESSOR_FACILITY "daemon"
-#define PROCESSOR_PRIORITY "warning"
-#define PROCESSOR_PRI 1
-#define PROCESSOR_CLASS "None"
-#define PROCESSOR_REV "0"
-#define PROCESSOR_TAG NULL
-#define PROCESSOR_GENERATOR_ID 100
+typedef struct _Sagan_Track_Clients_IPC _Sagan_Track_Clients_IPC;
 
-typedef struct _Sagan_Track_Clients _Sagan_Track_Clients;
-struct _Sagan_Track_Clients
-{
-    char    host[64];
-    uint64_t utime;
-    sbool   status;
+struct _Sagan_Track_Clients_IPC {
+    uint32_t host_u32;
+    long     utime;
+    int	     expire;
+    sbool    status;
 };
 
-
-int Sagan_Track_Clients ( _SaganProcSyslog * );
-void Sagan_Load_Tracking_Cache ( void );
-void Sagan_Track_Clients_Init ( void );
-
+int Sagan_Track_Clients ( uint32_t host_u32 );
