@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2015 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2015 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2016 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2016 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -25,8 +25,7 @@
 /* Storage for sagan-gen-msg.map */
 
 typedef struct _Sagan_Processor_Generator _Sagan_Processor_Generator;
-struct _Sagan_Processor_Generator
-{
+struct _Sagan_Processor_Generator {
     unsigned long generatorid;
     unsigned long alertid;
     char generator_msg[512];
