@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2015 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2015 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2016 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2016 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -24,8 +24,7 @@
 
 
 typedef struct _Sagan_Ignorelist _Sagan_Ignorelist;
-struct _Sagan_Ignorelist
-{
+struct _Sagan_Ignorelist {
     char ignore_string[256];
 };
 
