@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2015 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2015 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2016 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2016 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -51,7 +51,7 @@
 #endif
 
 #if defined(HAVE_DNET_H) || defined(HAVE_DUMBNET_H)
-uint64_t unified_event_id;
+uintmax_t unified_event_id;
 #endif
 
 struct _SaganCounters *counters;
@@ -78,33 +78,29 @@ void Sagan_Output( _SaganEvent *Event )
 
 #if defined(HAVE_DNET_H) || defined(HAVE_DUMBNET_H)
 
-    if ( config->sagan_unified2_flag )
-        {
-            Sagan_Unified2( Event );
-            Sagan_Unified2LogPacketAlert( Event );
+    if ( config->sagan_unified2_flag && rulestruct[Event->found].flowbit_nounified2 == 0 ) {
+        Sagan_Unified2( Event );
+        Sagan_Unified2LogPacketAlert( Event );
 
-            if ( Event->host[0] != '\0' )
-                {
-                    Sagan_WriteExtraData( Event, EVENT_INFO_XFF_IPV4 );
-                }
-
-            /* These get normalized in sagan-engine.c and passed via
-             * sagan-send-alert.c.  When adding more,  remember to add
-             * them there! */
-
-            if ( Event->normalize_http_uri[0] != '\0' )
-                {
-                    Sagan_WriteExtraData( Event, EVENT_INFO_HTTP_URI );
-                }
-
-            if ( Event->normalize_http_hostname[0] != '\0' )
-                {
-                    Sagan_WriteExtraData( Event, EVENT_INFO_HTTP_HOSTNAME );
-                }
-
-            unified_event_id++;
+        if ( Event->host[0] != '\0' ) {
+            Sagan_WriteExtraData( Event, EVENT_INFO_XFF_IPV4 );
         }
 
+        /* These get normalized in sagan-engine.c and passed via
+         * sagan-send-alert.c.  When adding more,  remember to add
+         * them there! */
+
+        if ( Event->normalize_http_uri[0] != '\0' ) {
+            Sagan_WriteExtraData( Event, EVENT_INFO_HTTP_URI );
+        }
+
+        if ( Event->normalize_http_hostname[0] != '\0' ) {
+            Sagan_WriteExtraData( Event, EVENT_INFO_HTTP_HOSTNAME );
+        }
+
+        unified_event_id++;
+    }
+
 #endif
 
     nonthread_alert_lock = 0;
@@ -118,10 +114,9 @@ void Sagan_Output( _SaganEvent *Event )
 
 #ifdef WITH_SYSLOG
 
-    if ( config->sagan_syslog_flag )
-        {
-            Sagan_Alert_Syslog( Event );
-        }
+    if ( config->sagan_syslog_flag ) {
+        Sagan_Alert_Syslog( Event );
+    }
 
 #endif
 
@@ -133,10 +128,9 @@ void Sagan_Output( _SaganEvent *Event )
 
 #ifdef WITH_SNORTSAM
 
-    if ( config->sagan_fwsam_flag && rulestruct[Event->found].fwsam_src_or_dst )
-        {
-            Sagan_FWSam( Event );
-        }
+    if ( config->sagan_fwsam_flag && rulestruct[Event->found].fwsam_src_or_dst ) {
+        Sagan_FWSam( Event );
+    }
 
 #endif
 
@@ -146,29 +140,26 @@ void Sagan_Output( _SaganEvent *Event )
 
 #ifdef HAVE_LIBESMTP
 
-    if ( config->sagan_esmtp_flag )
-        {
-            Sagan_ESMTP_Thread( Event );
-        }
+    if ( config->sagan_esmtp_flag ) {
+        Sagan_ESMTP_Thread( Event );
+    }
 #endif
 
     /****************************************************************************/
     /* External program support                                                 */
     /****************************************************************************/
 
-    if ( config->sagan_ext_flag )
-        {
-            Sagan_Ext_Thread( Event, config->sagan_extern );
-        }
+    if ( config->sagan_ext_flag ) {
+        Sagan_Ext_Thread( Event, config->sagan_extern );
+    }
 
     /****************************************************************************/
     /* External program via rule                                                */
     /****************************************************************************/
 
-    if (  rulestruct[Event->found].external_flag == 1 )
-        {
-            Sagan_Ext_Thread( Event, rulestruct[Event->found].external_program );
-        }
+    if (  rulestruct[Event->found].external_flag == 1 ) {
+        Sagan_Ext_Thread( Event, rulestruct[Event->found].external_program );
+    }
 
 
 }
