@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2015 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2015 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2016 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2016 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -25,8 +25,7 @@
 
 /* Reference structure */
 typedef struct _Ref_Struct _Ref_Struct;
-struct _Ref_Struct
-{
+struct _Ref_Struct {
     unsigned s_size_ref;
     char s_refid[512];
     char s_refurl[2048];
