@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2015 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2015 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2016 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2016 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -22,18 +22,5 @@
 #include "config.h"             /* From autoconf */
 #endif
 
-
-/****************************************************************************/
-/* 'Signal' thread options                                                  */
-/****************************************************************************/
-
-typedef struct _SaganSigArgs _SaganSigArgs;
-struct _SaganSigArgs
-{
-    int daemonize;
-    uint64_t cid;
-};
-
-
-void Sig_Handler( _SaganSigArgs * );
+void Sig_Handler( void );
 
