@@ -1,7 +1,7 @@
 /* $Id$ */
 /*
-** Copyright (C) 2009-2015 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2015 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2016 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2016 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -33,6 +33,7 @@
 #include <stdint.h>
 #include <pcre.h>
 #include <time.h>
+#include <arpa/inet.h>
 
 #ifdef HAVE_LIBMAXMINDDB
 #include <maxminddb.h>
@@ -60,54 +61,73 @@ void    Sagan_Chroot( const char * );
 char   *Remove_Return(char *);
 char   *Remove_Spaces(char *);
 char   *Between_Quotes( char * );
-double CalcPct(uint64_t, uint64_t);
+double CalcPct(uintmax_t, uintmax_t);
 char   *Replace_String(char *, char *, char *);
 char   *Get_Filename(char *);
 
+uintmax_t Sagan_Value_To_Seconds (char *, uintmax_t);
+
 typedef struct _SaganDNSCache _SaganDNSCache;
-struct _SaganDNSCache
-{
+struct _SaganDNSCache {
 
     char hostname[64];
     char src_ip[20];
 };
 
+typedef struct _Sagan_IPC_Counters _Sagan_IPC_Counters;
+struct _Sagan_IPC_Counters {
+
+    int  flowbit_count;
+    int	 thresh_count_by_src;
+    int	 thresh_count_by_dst;
+    int	 thresh_count_by_dstport;
+    int  thresh_count_by_srcport;
+    int	 thresh_count_by_username;
+    int	 after_count_by_src;
+    int	 after_count_by_dst;
+    int  after_count_by_srcport;
+    int	 after_count_by_dstport;
+    int	 after_count_by_username;
+
+    int	 track_client_count;
+    int  track_clients_client_count;
+    int  track_clients_down;
+
+};
+
+
 typedef struct _SaganCounters _SaganCounters;
-struct _SaganCounters
-{
+struct _SaganCounters {
 
-    uint64_t threshold_total;
-    uint64_t after_total;
-    uint64_t sagantotal;
-    uint64_t saganfound;
-    uint64_t sagan_output_drop;
-    uint64_t sagan_processor_drop;
-    uint64_t sagan_log_drop;
-    uint64_t dns_cache_count;
-    uint64_t dns_miss_count;
-    uint64_t fwsam_count;
-    uint64_t ignore_count;
-    uint64_t blacklist_count;
+    uintmax_t threshold_total;
+    uintmax_t after_total;
+    uintmax_t sagantotal;
+    uintmax_t saganfound;
+    uintmax_t sagan_output_drop;
+    uintmax_t sagan_processor_drop;
+    uintmax_t sagan_log_drop;
+    uintmax_t dns_cache_count;
+    uintmax_t dns_miss_count;
+    uintmax_t fwsam_count;
+    uintmax_t ignore_count;
+    uintmax_t blacklist_count;
 
-    uint64_t alert_total;
+    uintmax_t alert_total;
 
-    uint64_t malformed_host;
-    uint64_t malformed_facility;
-    uint64_t malformed_priority;
-    uint64_t malformed_level;
-    uint64_t malformed_tag;
-    uint64_t malformed_date;
-    uint64_t malformed_time;
-    uint64_t malformed_program;
-    uint64_t malformed_message;
+    uintmax_t malformed_host;
+    uintmax_t malformed_facility;
+    uintmax_t malformed_priority;
+    uintmax_t malformed_level;
+    uintmax_t malformed_tag;
+    uintmax_t malformed_date;
+    uintmax_t malformed_time;
+    uintmax_t malformed_program;
+    uintmax_t malformed_message;
 
-    uint64_t worker_thread_exhaustion;
+    uintmax_t worker_thread_exhaustion;
 
-    uint64_t track_clients_client_count;                /* sagan-track-clients processor */
-    uint64_t track_clients_down;
-
-    uint64_t blacklist_hit_count;
-    uint64_t blacklist_lookup_count;
+    uintmax_t blacklist_hit_count;
+    uintmax_t blacklist_lookup_count;
 
     int	     thread_output_counter;
     int	     thread_processor_counter;
@@ -142,38 +162,43 @@ struct _SaganCounters
     int      brointel_cert_hash_count;
     int      brointel_dups;
 
-#ifdef HAVE_LIBLOGNORM
-    int liblognormtoload_count;
-#endif
+    uintmax_t follow_flow_total;			/* This will only be needed if follow_flow is an option */
+    uintmax_t follow_flow_drop;			/* Amount of flows that did not match and were dropped */
 
 #ifdef HAVE_LIBMAXMINDDB
-    uint64_t geoip2_hit;				/* GeoIP2 hit count */
-    uint64_t geoip2_lookup;				/* Total lookups */
-    uint64_t geoip2_miss;				/* Misses (country not found) */
+    uintmax_t geoip2_hit;				/* GeoIP2 hit count */
+    uintmax_t geoip2_lookup;				/* Total lookups */
+    uintmax_t geoip2_miss;				/* Misses (country not found) */
 #endif
 
 #ifdef WITH_BLUEDOT
-    uint64_t bluedot_ip_cache_count;                      /* Bluedot cache processor */
-    uint64_t bluedot_ip_cache_hit;                        /* Bluedot hit's from Cache */
-    uint64_t bluedot_ip_positive_hit;
-    uint64_t bluedot_ip_total;
+    uintmax_t bluedot_ip_cache_count;                      /* Bluedot cache processor */
+    uintmax_t bluedot_ip_cache_hit;                        /* Bluedot hit's from Cache */
+    uintmax_t bluedot_ip_positive_hit;
+    uintmax_t bluedot_ip_total;
 
-    uint64_t bluedot_error_count;
+    uintmax_t bluedot_mdate;					   /* Hits , but where over a modification date */
+    uintmax_t bluedot_cdate;            	                   /* Hits , but where over a creation date */
+    uintmax_t bluedot_mdate_cache;                                 /* Hits from cache , but where over a modification date */
+    uintmax_t bluedot_cdate_cache;      			   /* Hits from cache , but where over a create date */
 
-    uint64_t bluedot_hash_cache_count;
-    uint64_t bluedot_hash_cache_hit;
-    uint64_t bluedot_hash_positive_hit;
-    uint64_t bluedot_hash_total;
 
-    uint64_t bluedot_url_cache_count;
-    uint64_t bluedot_url_cache_hit;
-    uint64_t bluedot_url_positive_hit;
-    uint64_t bluedot_url_total;
+    uintmax_t bluedot_error_count;
 
-    uint64_t bluedot_filename_cache_count;
-    uint64_t bluedot_filename_cache_hit;
-    uint64_t bluedot_filename_positive_hit;
-    uint64_t bluedot_filename_total;
+    uintmax_t bluedot_hash_cache_count;
+    uintmax_t bluedot_hash_cache_hit;
+    uintmax_t bluedot_hash_positive_hit;
+    uintmax_t bluedot_hash_total;
+
+    uintmax_t bluedot_url_cache_count;
+    uintmax_t bluedot_url_cache_hit;
+    uintmax_t bluedot_url_positive_hit;
+    uintmax_t bluedot_url_total;
+
+    uintmax_t bluedot_filename_cache_count;
+    uintmax_t bluedot_filename_cache_hit;
+    uintmax_t bluedot_filename_positive_hit;
+    uintmax_t bluedot_filename_total;
 
     int bluedot_cat_count;
 
@@ -181,15 +206,14 @@ struct _SaganCounters
 
 
 #ifdef HAVE_LIBESMTP
-    uint64_t esmtp_count_success;
-    uint64_t esmtp_count_failed;
+    uintmax_t esmtp_count_success;
+    uintmax_t esmtp_count_failed;
 #endif
 
 };
 
 typedef struct _SaganDebug _SaganDebug;
-struct _SaganDebug
-{
+struct _SaganDebug {
 
     sbool debugsyslog;
     sbool debugload;
@@ -201,6 +225,7 @@ struct _SaganDebug
     sbool debugbrointel;
     sbool debugmalformed;
     sbool debuglimits;
+    sbool debugipc;
 
 #ifdef HAVE_LIBMAXMINDDB
     sbool debuggeoip2;
@@ -226,8 +251,7 @@ struct _SaganDebug
 
 };
 
-typedef struct _Sagan_Proc_Syslog
-{
+typedef struct _Sagan_Proc_Syslog {
     char syslog_host[50];
     char syslog_facility[50];
     char syslog_priority[50];
@@ -237,10 +261,10 @@ typedef struct _Sagan_Proc_Syslog
     char syslog_time[50];
     char syslog_program[50];
     char syslog_message[MAX_SYSLOGMSG];
+
 } _SaganProcSyslog;
 
-typedef struct _Sagan_Event
-{
+typedef struct _Sagan_Event {
 
     char *ip_src;
     char *ip_dst;
@@ -287,77 +311,122 @@ typedef struct _Sagan_Event
 } _SaganEvent;
 
 /* Thresholding structure by source */
-typedef struct thresh_by_src thresh_by_src;
-struct thresh_by_src
-{
+typedef struct thresh_by_src_ipc thresh_by_src_ipc;
+struct thresh_by_src_ipc {
     uint32_t ipsrc;
     int  count;
-    uint64_t utime;
-    char sid[32];
+    uintmax_t utime;
+    char sid[20];
+    int expire;
 };
 
+
 /* Thresholding structure by destination */
-typedef struct thresh_by_dst thresh_by_dst;
-struct thresh_by_dst
-{
+typedef struct thresh_by_dst_ipc thresh_by_dst_ipc;
+struct thresh_by_dst_ipc {
     uint32_t ipdst;
     int  count;
-    uint64_t utime;
-    char sid[32];
+    uintmax_t utime;
+    char sid[20];
+    int expire;
 };
 
+
+/* Thresholding structure by source port */
+typedef struct thresh_by_srcport_ipc thresh_by_srcport_ipc;
+struct thresh_by_srcport_ipc {
+    uint32_t ipsrcport;
+    int  count;
+    uint64_t utime;
+    char sid[20];
+    int expire;
+};
+
+/* Thresholding structure by destination port */
+typedef struct thresh_by_dstport_ipc thresh_by_dstport_ipc;
+struct thresh_by_dstport_ipc {
+    uint32_t ipdstport;
+    int  count;
+    uint64_t utime;
+    char sid[20];
+    int expire;
+};
+
+
 /* Thesholding structure by username */
-typedef struct thresh_by_username thresh_by_username;
-struct thresh_by_username
-{
+typedef struct thresh_by_username_ipc thresh_by_username_ipc;
+struct thresh_by_username_ipc {
     char username[128];
     int  count;
-    uint64_t utime;
-    char sid[32];
+    uintmax_t utime;
+    char sid[20];
+    int expire;
 };
 
-
 /* After structure by source */
-typedef struct after_by_src after_by_src;
-struct after_by_src
-{
+typedef struct after_by_src_ipc after_by_src_ipc;
+struct after_by_src_ipc {
     uint32_t ipsrc;
     int  count;
-    uint64_t utime;
-    char sid[32];
+    uintmax_t utime;
+    char sid[20];
+    int expire;
 };
 
 /* After structure by destination */
-typedef struct after_by_dst after_by_dst;
-struct after_by_dst
-{
+typedef struct after_by_dst_ipc after_by_dst_ipc;
+struct after_by_dst_ipc {
     uint32_t ipdst;
     int  count;
-    uint64_t utime;
-    char sid[32];
+    uintmax_t utime;
+    char sid[20];
+    int expire;
 };
 
-/* After structure by username */
-typedef struct after_by_username after_by_username;
-struct after_by_username
-{
-    char username[128];
+/* After structure by source port */
+typedef struct after_by_srcport_ipc after_by_srcport_ipc;
+struct after_by_srcport_ipc {
+    uint32_t ipsrcport;
     int  count;
     uint64_t utime;
-    char sid[32];
+    char sid[20];
+    int expire;
+};
+
+/* After structure by destination port */
+typedef struct after_by_dstport_ipc after_by_dstport_ipc;
+struct after_by_dstport_ipc {
+    uint32_t ipdstport;
+    int  count;
+    uint64_t utime;
+    char sid[20];
+    int expire;
 };
 
 
+/* After structure by username */
+typedef struct after_by_username_ipc after_by_username_ipc;
+struct after_by_username_ipc {
+    char username[128];
+    int  count;
+    uintmax_t utime;
+    char sid[20];
+    int expire;
+};
+
 typedef struct _SaganVar _SaganVar;
-struct _SaganVar
-{
+struct _SaganVar {
     char var_name[MAX_VAR_NAME_SIZE];
     char var_value[MAX_VAR_VALUE_SIZE];
 };
 
+typedef struct network_addr {
+    in_addr_t addr;
+    int pfx;
+} network_addr_t;
+
 typedef struct _Sagan_Processor_Info _Sagan_Processor_Info;
-struct _Sagan_Processor_Info
-{
+struct _Sagan_Processor_Info {
 
     char *processor_name;
     char *processor_facility;
@@ -369,12 +438,14 @@ struct _Sagan_Processor_Info
     int   processor_generator_id;
 };
 
-
 void Sagan_Log( int, const char *, ... );
 void Sagan_Droppriv( void );
 char *DNS_Lookup( char * );
 char *Sagan_Var_To_Value(char *);
+
 uint32_t IP2Bit (char * );
+char *Bit2IP(uint32_t);
+
 int Sagan_Validate_HEX (const char *);
 char *Sagan_Content_Pipe(char *, int, const char *);
 sbool is_rfc1918 ( uint32_t );
@@ -383,6 +454,16 @@ int Sagan_Character_Count ( char *, char *);
 sbool Sagan_Wildcard( char *, char *);
 void Sagan_Open_Log_File( sbool, int );
 int Sagan_Check_Var(const char *);
+char *Sagan_u32_Time_To_Human ( uintmax_t );
+char *Netaddr_To_Range( char * );
+char *Strip_Chars(const char *string, const char *chars);
+sbool Is_IP (char *str);
+
+char *Sagan_Return_Date( uintmax_t );
+char *Sagan_Return_Time( uintmax_t );
+
+sbool Sagan_File_Lock ( int );
+sbool Sagan_File_Unlock ( int );
 
 #if defined(F_GETPIPE_SZ) && defined(F_SETPIPE_SZ)
 void Sagan_Set_Pipe_Size( FILE * );
